@@ -5,14 +5,22 @@ within your Python programs.
 """
 
 from functools import wraps
-import cPickle
+try:
+    import cPickle as pickle
+except ImportError:
+    import pickle
 
 from redis import Redis
 
 
 __all__ = ['HotQueue']
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
+
+
+def key_for_name(name):
+    """Return the key name used to store the given queue name in Redis."""
+    return 'hotqueue:%s' % name
 
 
 class HotQueue(object):
@@ -40,10 +48,8 @@ class HotQueue(object):
     
     @property
     def key(self):
-        """Return the key name used to store this queue in Redis, which is
-        a concatenation of "hotqueue:" and :attr:`name`.
-        """
-        return 'hotqueue:%s' % self.name
+        """Return the key name used to store this queue in Redis."""
+        return key_for_name(self.name)
     
     def clear(self):
         """Clear the queue of all messages, deleting the Redis key."""
@@ -93,7 +99,7 @@ class HotQueue(object):
         else:
             msg = self.__redis.lpop(self.key)
         if msg is not None:
-            msg = cPickle.loads(msg)
+            msg = pickle.loads(msg)
         return msg
     
     def put(self, *msgs):
@@ -103,7 +109,7 @@ class HotQueue(object):
         >>> queue.put('another message')
         """
         for msg in msgs:
-            msg = cPickle.dumps(msg)
+            msg = pickle.dumps(msg)
             self.__redis.rpush(self.key, msg)
     
     def worker(self, *args, **kwargs):
